@@ -12,10 +12,10 @@ namespace waybar {
 
 class Group : public AModule {
  public:
-  Group(const std::string&, const Bar&, const Json::Value&);
+  Group(const std::string&, const std::string&, const Json::Value&, bool);
   ~Group() = default;
-  auto update() -> void;
-  operator Gtk::Widget&();
+  auto update() -> void override;
+  operator Gtk::Widget&() override;
   Gtk::Box box;
 };
 
