@@ -15,9 +15,9 @@ namespace waybar::modules {
 class Custom : public ALabel {
  public:
   Custom(const std::string&, const std::string&, const Json::Value&);
-  ~Custom();
-  auto update() -> void;
-  void refresh(int /*signal*/);
+  virtual ~Custom();
+  auto update() -> void override;
+  void refresh(int /*signal*/) override;
 
  private:
   void delayWorker();
@@ -25,8 +25,8 @@ class Custom : public ALabel {
   void parseOutputRaw();
   void parseOutputJson();
   void handleEvent();
-  bool handleScroll(GdkEventScroll* e);
-  bool handleToggle(GdkEventButton* const& e);
+  bool handleScroll(GdkEventScroll* e) override;
+  bool handleToggle(GdkEventButton* const& e) override;
 
   const std::string name_;
   std::string text_;
