@@ -6,6 +6,8 @@
 #include <string>
 #include <thread>
 
+#include "util/json.hpp"
+
 namespace waybar::modules::hyprland {
 
 class EventHandler {
@@ -22,12 +24,14 @@ class IPC {
   void unregisterForIPC(EventHandler*);
 
   std::string getSocket1Reply(const std::string& rq);
+  Json::Value getSocket1JsonReply(const std::string& rq);
 
  private:
   void startIPC();
   void parseIPC(const std::string&);
 
   std::mutex callbackMutex;
+  util::JsonParser parser_;
   std::list<std::pair<std::string, EventHandler*>> callbacks;
 };
 
