@@ -19,8 +19,8 @@ namespace waybar::modules {
 class KeyboardState : public AModule {
  public:
   KeyboardState(const std::string&, const waybar::Bar&, const Json::Value&);
-  ~KeyboardState();
-  auto update() -> void;
+  virtual ~KeyboardState();
+  auto update() -> void override;
 
  private:
   auto tryAddDevice(const std::string&) -> void;
