@@ -36,7 +36,8 @@ waybar::modules::Battery::~Battery() {
   }
   close(global_watch_fd_);
 
-  for (auto it = batteries_.cbegin(); it != batteries_.cend(); it++) {
+  for (auto it = batteries_.cbegin(), next_it = it; it != batteries_.cend(); it = next_it) {
+    ++next_it;
     auto watch_id = (*it).second;
     if (watch_id >= 0) {
       inotify_rm_watch(battery_watch_fd_, watch_id);
@@ -505,12 +506,12 @@ const std::tuple<uint8_t, float, std::string, float> waybar::modules::Battery::g
 
     float time_remaining{0.0f};
     if (status == "Discharging" && time_to_empty_now_exists) {
-      if (time_to_empty_now != 0) time_remaining = (float)time_to_empty_now / 1000.0f;
+      if (time_to_empty_now != 0) time_remaining = (float)time_to_empty_now / 3600.0f;
     } else if (status == "Discharging" && total_power_exists && total_energy_exists) {
       if (total_power != 0) time_remaining = (float)total_energy / total_power;
     } else if (status == "Charging" && time_to_full_now_exists) {
       if (time_to_full_now_exists && (time_to_full_now != 0))
-        time_remaining = -(float)time_to_full_now / 1000.0f;
+        time_remaining = -(float)time_to_full_now / 3600.0f;
       // If we've turned positive it means the battery is past 100% and so just report that as no
       // time remaining
       if (time_remaining > 0.0f) time_remaining = 0.0f;
@@ -604,7 +605,7 @@ const std::string waybar::modules::Battery::formatTimeRemaining(float hoursRemai
     format = config_["format-time"].asString();
   }
   std::string zero_pad_minutes = fmt::format("{:02d}", minutes);
-  return fmt::format(format, fmt::arg("H", full_hours), fmt::arg("M", minutes),
+  return fmt::format(fmt::runtime(format), fmt::arg("H", full_hours), fmt::arg("M", minutes),
                      fmt::arg("m", zero_pad_minutes));
 }
 
@@ -644,7 +645,8 @@ auto waybar::modules::Battery::update() -> void {
     } else if (config_["tooltip-format"].isString()) {
       tooltip_format = config_["tooltip-format"].asString();
     }
-    label_.set_tooltip_text(fmt::format(tooltip_format, fmt::arg("timeTo", tooltip_text_default),
+    label_.set_tooltip_text(fmt::format(fmt::runtime(tooltip_format),
+                                        fmt::arg("timeTo", tooltip_text_default),
                                         fmt::arg("power", power), fmt::arg("capacity", capacity),
                                         fmt::arg("time", time_remaining_formatted)));
   }
@@ -665,9 +667,9 @@ auto waybar::modules::Battery::update() -> void {
   } else {
     event_box_.show();
     auto icons = std::vector<std::string>{status + "-" + state, status, state};
-    label_.set_markup(fmt::format(format, fmt::arg("capacity", capacity), fmt::arg("power", power),
-                                  fmt::arg("icon", getIcon(capacity, icons)),
-                                  fmt::arg("time", time_remaining_formatted)));
+    label_.set_markup(fmt::format(
+        fmt::runtime(format), fmt::arg("capacity", capacity), fmt::arg("power", power),
+        fmt::arg("icon", getIcon(capacity, icons)), fmt::arg("time", time_remaining_formatted)));
   }
   // Call parent update
   ALabel::update();
