@@ -58,11 +58,11 @@ auto waybar::modules::Disk::update() -> void {
     event_box_.hide();
   } else {
     event_box_.show();
-    label_.set_markup(
-        fmt::format(format, stats.f_bavail * 100 / stats.f_blocks, fmt::arg("free", free),
-                    fmt::arg("percentage_free", stats.f_bavail * 100 / stats.f_blocks),
-                    fmt::arg("used", used), fmt::arg("percentage_used", percentage_used),
-                    fmt::arg("total", total), fmt::arg("path", path_)));
+    label_.set_markup(fmt::format(
+        fmt::runtime(format), stats.f_bavail * 100 / stats.f_blocks, fmt::arg("free", free),
+        fmt::arg("percentage_free", stats.f_bavail * 100 / stats.f_blocks), fmt::arg("used", used),
+        fmt::arg("percentage_used", percentage_used), fmt::arg("total", total),
+        fmt::arg("path", path_)));
   }
 
   if (tooltipEnabled()) {
@@ -70,11 +70,11 @@ auto waybar::modules::Disk::update() -> void {
     if (config_["tooltip-format"].isString()) {
       tooltip_format = config_["tooltip-format"].asString();
     }
-    label_.set_tooltip_text(
-        fmt::format(tooltip_format, stats.f_bavail * 100 / stats.f_blocks, fmt::arg("free", free),
-                    fmt::arg("percentage_free", stats.f_bavail * 100 / stats.f_blocks),
-                    fmt::arg("used", used), fmt::arg("percentage_used", percentage_used),
-                    fmt::arg("total", total), fmt::arg("path", path_)));
+    label_.set_tooltip_text(fmt::format(
+        fmt::runtime(tooltip_format), stats.f_bavail * 100 / stats.f_blocks, fmt::arg("free", free),
+        fmt::arg("percentage_free", stats.f_bavail * 100 / stats.f_blocks), fmt::arg("used", used),
+        fmt::arg("percentage_used", percentage_used), fmt::arg("total", total),
+        fmt::arg("path", path_)));
   }
   // Call parent update
   ALabel::update();
