@@ -19,7 +19,7 @@ Host::Host(const std::size_t id, const Json::Value& config, const Bar& bar,
 
 Host::~Host() {
   if (bus_name_id_ > 0) {
-    Gio::DBus::unwatch_name(bus_name_id_);
+    Gio::DBus::unown_name(bus_name_id_);
     bus_name_id_ = 0;
   }
   if (watcher_id_ > 0) {
